=====
Usage
=====

To use Django Amazon Translate in a project you will need to add it to
your list of INSTALLED_APPS::

    INSTALLED_APPS = [
        # Your other apps
        # ...
        'django_amazon_translate',
    ]

This will the provide you an extra manage command called
'auto_translate_text'.

